package com.zbf.system.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper; //添加
import com.zbf.system.domain.TBaseFinancialClass;

/**
 * 财务分类Mapper接口
 *
 * @author sunits
 * @date 2024-06-28
 */
public interface TBaseFinancialClassMapper extends BaseMapper<TBaseFinancialClass> //修改
{
    /**
     * 查询财务分类
     *
     * @param id 财务分类主键
     * @return 财务分类
     */
    public TBaseFinancialClass selectTBaseFinancialClassById(Long id);

    /**
     * 查询财务分类列表
     *
     * @param tBaseFinancialClass 财务分类
     * @return 财务分类集合
     */
    public List<TBaseFinancialClass> selectTBaseFinancialClassList(TBaseFinancialClass tBaseFinancialClass);

    /**
     * 新增财务分类
     *
     * @param tBaseFinancialClass 财务分类
     * @return 结果
     */
    public int insertTBaseFinancialClass(TBaseFinancialClass tBaseFinancialClass);

    /**
     * 修改财务分类
     *
     * @param tBaseFinancialClass 财务分类
     * @return 结果
     */
    public int updateTBaseFinancialClass(TBaseFinancialClass tBaseFinancialClass);

    /**
     * 删除财务分类
     *
     * @param id 财务分类主键
     * @return 结果
     */
    public int deleteTBaseFinancialClassById(Long id);

    /**
     * 批量删除财务分类
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTBaseFinancialClassByIds(Long[] ids);

    /**
     * 批量启用财务分类
     *
     * @param ids 需要启用的数据主键集合
     * @return 结果
     */
    public int enableTBaseFinancialClassByIds(Long[] ids);

    /**
     * 批量禁用财务分类
     *
     * @param ids 需要禁用的数据主键集合
     * @return 结果
     */
    public int disabledTBaseFinancialClassByIds(Long[] ids);

}
